FlowEngine

Struct FlowEngine 

pub struct FlowEngine { /* private fields */ }

Implementations

Source

impl FlowEngine

pub fn process( &self, txn: &mut FlowTransaction, change: Change, flow_id: FlowId, ) -> Result<()>

pub fn process_tick( &self, txn: &mut FlowTransaction, flow_id: FlowId, timestamp: DateTime, ) -> Result<()>

Source

impl FlowEngine

pub fn register( &mut self, txn: &mut CommandTransaction, flow: FlowDag, ) -> Result<()>

pub fn register_with_transaction( &mut self, txn: &mut Transaction<'_>, flow: FlowDag, ) -> Result<()>

Source

impl FlowEngine

pub fn new( catalog: Catalog, executor: Executor, event_bus: EventBus, runtime_context: RuntimeContext, custom_operators: Arc<HashMap<String, OperatorFactory>>, ) -> Self

pub fn flow_ids(&self) -> BTreeSet<FlowId>

Returns a set of all currently registered flow IDs

pub fn clear(&mut self)

Clears all registered flows, operators, sources, sinks, dependency graph, and backfill versions

pub fn get_dependency_graph(&self) -> FlowDependencyGraph

pub fn get_flows_depending_on_table(&self, table_id: TableId) -> Vec<FlowId>

pub fn get_flows_depending_on_view(&self, view_id: ViewId) -> Vec<FlowId>

pub fn get_flow_producing_view(&self, view_id: ViewId) -> Option<FlowId>

pub fn calculate_execution_order(&self) -> Vec<FlowId>