pub struct TestOperator {
pub id: FlowNodeId,
pub layout: RowShape,
pub key_types: Vec<Type>,
}Expand description
Test operator implementation for stateful traits
Fields
id: FlowNodeIdlayout: RowShapekey_types: Vec<Type>Implementations
Sourceimpl TestOperator
impl TestOperator
Sourcepub fn new(id: FlowNodeId) -> Self
pub fn new(id: FlowNodeId) -> Self
Create a new test operator with a complex shape
Sourcepub fn simple(id: FlowNodeId) -> Self
pub fn simple(id: FlowNodeId) -> Self
Create a simple test operator with a single column
Sourcepub fn with_key_types(id: FlowNodeId, key_types: Vec<Type>) -> Self
pub fn with_key_types(id: FlowNodeId, key_types: Vec<Type>) -> Self
Create a test operator with custom key types