pub struct SameThreadedWorker;Expand description
Same threaded worker that processes units of work sequentially from a deque
This is the initial implementation that can be easily replaced with parallel implementations later.
Implementations