pub struct FFIOperatorLoader { /* private fields */ }Expand description
FFI operator loader for dynamic libraries This is meant to be used as a singleton via get_global_loader()
Implementations
Sourceimpl FFIOperatorLoader
impl FFIOperatorLoader
Sourcepub fn load_operator(
&mut self,
path: &Path,
config: &[u8],
operator_id: FlowNodeId,
) -> FFIResult<FFIOperator>
pub fn load_operator( &mut self, path: &Path, config: &[u8], operator_id: FlowNodeId, ) -> FFIResult<FFIOperator>
Sourcepub fn create_operator_by_name(
&mut self,
operator_name: &str,
operator_id: FlowNodeId,
config: &[u8],
) -> FFIResult<FFIOperator>
pub fn create_operator_by_name( &mut self, operator_name: &str, operator_id: FlowNodeId, config: &[u8], ) -> FFIResult<FFIOperator>
Create an operator instance from an already loaded library by name
Arguments
operator_name- Name of the operator typeoperator_id- Node ID for this operator instanceconfig- Configuration data for the operator
Returns
Ok(FFIOperator)- Successfully created operatorErr(FFIError)- Creation failed
Sourcepub fn has_operator(&self, operator_name: &str) -> bool
pub fn has_operator(&self, operator_name: &str) -> bool
Check if an operator name is registered
Sourcepub fn unload_library(&mut self, path: &Path) -> FFIResult<()>
pub fn unload_library(&mut self, path: &Path) -> FFIResult<()>
Sourcepub fn loaded_count(&self) -> usize
pub fn loaded_count(&self) -> usize
Get the number of loaded libraries