pub struct ParallelWorkerPool { /* private fields */ }Expand description
Parallel worker pool that uses the sub-worker thread pool for execution
Each flow’s units are submitted as a separate high-priority task to the worker pool. Different flows can execute in parallel, but each flow’s units are processed sequentially to maintain version ordering.
Implementations
Sourceimpl ParallelWorkerPool
impl ParallelWorkerPool
Sourcepub fn new(scheduler: SchedulerService) -> Self
pub fn new(scheduler: SchedulerService) -> Self
Create a new parallel worker pool