pub struct UnitsOfWork(/* private fields */);Expand description
A collection of units of work grouped by flow
Each inner vector represents one flow’s units, ordered by version. The flow’s units must be processed sequentially to maintain version ordering. Different flows (outer vector) can be processed in parallel.
Implementations
Sourceimpl UnitsOfWork
impl UnitsOfWork
Sourcepub fn new(flow_units: Vec<Vec<UnitOfWork>>) -> Self
pub fn new(flow_units: Vec<Vec<UnitOfWork>>) -> Self
Create a new UnitsOfWork from a vector of flow units
Sourcepub fn flow_count(&self) -> usize
pub fn flow_count(&self) -> usize
Get the number of flows
Sourcepub fn total_units(&self) -> usize
pub fn total_units(&self) -> usize
Get the total number of units across all flows
Sourcepub fn as_inner(&self) -> &Vec<Vec<UnitOfWork>>
pub fn as_inner(&self) -> &Vec<Vec<UnitOfWork>>
Get a reference to the inner vector
Sourcepub fn into_inner(self) -> Vec<Vec<UnitOfWork>>
pub fn into_inner(self) -> Vec<Vec<UnitOfWork>>
Consume self and return the inner vector